# kkpyutil
Small utility frequently used by myself for daily Python work.
- No dependency on third-party Python modules, so it alwyas run
- Some functions use system builtin executable or essential programs, so runs will fail if those are not installed separately

## INSTALL

```shell
pip3 install kkpyutil
```
